@@ -1,5 +1,5 @@
 import {expectType} from 'tsd';
-import registryUrl = require('.');
+import registryUrl from './index.js';
 
 expectType<string>(registryUrl());
 expectType<string>(registryUrl('@myco'));
